=========
Changelog
=========

0.1.2 (2020-11-18)
------------------

* ``coinflip.collections.bins`` now uses ``OrderedDict`` under the hood.


0.1.1 (2020-11-16)
------------------

* Reference implementation available in ``coinflip.randtests_refimpl`` (requires the `refimpl` extra).
* Docstrings for all the randomness tests in ``coinflip.randtests``.


0.1.0 (2020-11-09)
------------------

* First beta release on PyPI.
